@@ -36,12 +36,16 @@ describe('static api', function () {
     expect(typeof axios.create).toEqual('function');
   });
 
-  it('should have Cancel, CancelToken, and isCancel properties', function () {
+  it('should have CanceledError, CancelToken, and isCancel properties', function () {
     expect(typeof axios.Cancel).toEqual('function');
     expect(typeof axios.CancelToken).toEqual('function');
     expect(typeof axios.isCancel).toEqual('function');
   });
 
+  it('should have getUri method', function() {
+    expect(typeof axios.getUri).toEqual('function');
+  });
+
   it('should have isAxiosError properties', function () {
     expect(typeof axios.isAxiosError).toEqual('function');
   });
