@@ -13,15 +13,20 @@ describe('instance', function () {
     for (var prop in axios) {
       if ([
         'Axios',
+        'AxiosError',
         'create',
         'Cancel',
+        'CanceledError',
         'CancelToken',
         'isCancel',
         'all',
         'spread',
+        'getUri',
         'isAxiosError',
         'VERSION',
-        'default'].indexOf(prop) > -1) {
+        'default',
+        'toFormData'
+      ].indexOf(prop) > -1) {
         continue;
       }
       expect(typeof instance[prop]).toBe(typeof axios[prop]);
@@ -112,4 +117,40 @@ describe('instance', function () {
       }, 100);
     });
   });
+
+  it('should have getUri on the instance', function() {
+    var instance = axios.create({
+      baseURL: 'https://api.example.com'
+    });
+    var options = {
+      url: 'foo/bar',
+      params: {
+        name: 'axios'
+      }
+    };
+    expect(instance.getUri(options)).toBe('https://api.example.com/foo/bar?name=axios');
+  });
+
+  it('should correctly build url without baseURL', function () {
+    var instance = axios.create();
+    var options = {
+      url: 'foo/bar?foo=bar',
+      params: {
+        name: 'axios'
+      }
+    };
+    expect(instance.getUri(options)).toBe('foo/bar?foo=bar&name=axios');
+  });
+
+  it('should correctly discard url hash mark', function () {
+    var instance = axios.create();
+    var options = {
+      baseURL: 'https://api.example.com',
+      url: 'foo/bar?foo=bar#hash',
+      params: {
+        name: 'axios'
+      }
+    };
+    expect(instance.getUri(options)).toBe('https://api.example.com/foo/bar?foo=bar&name=axios');
+  });
 });
